@@ -4,6 +4,7 @@ from __future__ import unicode_literals
 from functools import wraps
 from . import http
 
+
 def permit(test_func):
     '''Decorate a handler to control access'''
     def decorator(view_func):
@@ -26,7 +27,7 @@ permit_staff = permit(
 
 def permit_groups(*groups):
     def in_groups(request, *args):
-        return request.user.groups.filter(name__in=args).exists()
+        return request.user.groups.filter(name__in=groups).exists()
     return permit(
         lambda self, *args, **kwargs: in_groups(self.request, *groups)
     )
